@@ -20,6 +20,7 @@ import inspect
 from abc import ABC
 from collections import OrderedDict
 from enum import Enum
+from pathlib import Path
 from typing import Any, Callable, List, Optional, TypeVar, Union
 
 from flytekit.core.base_task import Task, TaskResolverMixin
@@ -103,6 +104,7 @@ class PythonFunctionTask(PythonAutoContainerTask[T]):
         ignore_input_vars: Optional[List[str]] = None,
         execution_mode: Optional[ExecutionBehavior] = ExecutionBehavior.DEFAULT,
         task_resolver: Optional[TaskResolverMixin] = None,
+        dockerfile_path: Optional[Path] = None,
         **kwargs,
     ):
         """
@@ -146,12 +148,14 @@ class PythonFunctionTask(PythonAutoContainerTask[T]):
                 )
         self._task_function = task_function
         self._execution_mode = execution_mode
+        self._dockerfile_path = dockerfile_path
 
         def _hash_function(task_func: Callable):
             func_str = inspect.getsource(task_func)
             module = ast.parse(func_str)
 
-            assert len(module.body) == 1 and isinstance(module.body[0], ast.FunctionDef)
+            if not (len(module.body) == 1 and isinstance(module.body[0], ast.FunctionDef)):
+                raise ValueError(f"Unable to hash callable {self._task_function}")
 
             # Function name should not effect hash
             func_node = module.body[0]
@@ -179,6 +183,10 @@ class PythonFunctionTask(PythonAutoContainerTask[T]):
     def execution_mode(self) -> ExecutionBehavior:
         return self._execution_mode
 
+    @property
+    def dockerfile_path(self) -> Path:
+        return self._dockerfile_path
+
     @property
     def task_function(self):
         return self._task_function
