@@ -167,7 +167,7 @@ class LatchPersistence(DataPersistence):
                     timeout=90,
                 )
                 break
-            except requests.exceptions.ConnectionError:
+            except requests.exceptions.ConnectionError as e:
                 attempts += 1
                 if attempts >= 3:
                     raise e
